Method: MysqlBackup::Entity::Files::Myisam#datadir

Defined in:
lib/mysql_backup/entity/files/myisam.rb

#datadirObject

Takes the following arguments:

:datadir => The MySQL data directory.

The following files will be backed up with the default base_dir and ib_basename:

/var/lib/mysql/*/*.MYD - all files in any directory that contain one or more *.MYD files


36
37
38
# File 'lib/mysql_backup/entity/files/myisam.rb', line 36

def datadir
  @datadir
end